bloritsch 01/12/12 14:14:16
Modified: src/proposal/profile AbstractProfilePoint.java
EventsPerSampleProfilePoint.java
ValueProfilePoint.java
Added: src/proposal/profile PeekValueProfilePoint.java
Removed: src/proposal/profile PeakValueProfilePoint.java
Log:
fix spelling mistakes
Revision Changes Path
1.2 +1 -1
jakarta-avalon/src/proposal/profile/AbstractProfilePoint.java
Index: AbstractProfilePoint.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/proposal/profile/AbstractProfilePoint.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- AbstractProfilePoint.java 2001/12/12 21:58:52 1.1
+++ AbstractProfilePoint.java 2001/12/12 22:14:16 1.2
@@ -19,7 +19,7 @@
private final String m_name;
/**
- * Creates a MaxValueProfilePoint with an initial name.
+ * Initializes the ProfilePoint with a name.
*/
public AbstractProfilePoint( String name )
{
1.2 +2 -2
jakarta-avalon/src/proposal/profile/EventsPerSampleProfilePoint.java
Index: ValueProfilePoint.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/proposal/profile/ValueProfilePoint.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- ValueProfilePoint.java 2001/12/12 21:58:52 1.1
+++ ValueProfilePoint.java 2001/12/12 22:14:16 1.2
@@ -19,7 +19,7 @@
private int m_value = 0;
/**
- * Creates a MaxValueProfilePoint with an initial name.
+ * Creates a ValueProfilePoint with an initial name.
*/
public ValueProfilePoint( String name )
{
1.1
jakarta-avalon/src/proposal/profile/PeekValueProfilePoint.java
Index: EventsPerSampleProfilePoint.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/proposal/profile/EventsPerSampleProfilePoint.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- EventsPerSampleProfilePoint.java 2001/12/12 21:58:52 1.1
+++ EventsPerSampleProfilePoint.java 2001/12/12 22:14:16 1.2
@@ -19,9 +19,9 @@
private int m_value = 0;
/**
* Creates a MaxValueProfilePoint with an initial name.
*/
- public PeakValueProfilePoint( String name )
+ public EventsPerSampleProfilePoint( String name )
{
super( name );
}
@@ -19,9 +19,9 @@
private int m_value = 0;
/**
- * Creates a MaxValueProfilePoint with an initial name.
+ * Creates a EventsPerSampleProfilePoint with an initial name.
*/
1.2 +1 -1
jakarta-avalon/src/proposal/profile/ValueProfilePoint.java
Index: PeekValueProfilePoint.java
===================================================================
/*
* Copyright (C) The Apache Software Foundation. All rights reserved.
*
* This software is published under the terms of the Apache Software License
* version 1.1, a copy of which has been included with this distribution in
* the LICENSE.txt file.
*/
package org.apache.avalon.framework.profile;
/**
* The ProfilPoint interface is to mark objects that can be sampled by a
* Profiler. The interface only has one sampling method to simplify the items
* that can be sampled.
*
* @author <a href="mailto:[EMAIL PROTECTED]">Berin Loritsch</a>
*/
public class PeekValueProfilePoint extends AbstractProfilePoint
{
private int m_value = 0;
/**
* Creates a PeekValueProfilePoint with an initial name.
*/
public PeekValueProfilePoint( String name )
{
super( name );
}
/**
* Set the sample value
*/
public void setValue( int currentValue )
{
if ( currentValue > m_value )
{
m_value = currentValue;
}
}
/**
* Obtain the sample. All samples are an integer, so the profiled objects
* must measure quantity (numbers of items), rate (items/period), time in
* milliseconds, etc.
*/
public int getSample()
{
return m_value;
}
}
--
To unsubscribe, e-mail: <mailto:[EMAIL PROTECTED]>
For additional commands, e-mail: <mailto:[EMAIL PROTECTED]>